/*
 * $Id: link_bandwidth_calc.h,v 1.5 2001/06/22 22:07:04 laik Exp $
 *
 * This file contains information about the link bandwidth calculation 
 * routines.
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __LINK_BANDWIDTH_CALC_H__
#define __LINK_BANDWIDTH_CALC_H__

#include "dpcap_flow.h"

#include "kl_event.h"
#include "kl_list.h"
#include "kl_buffered_output.h"

#include "transport.h"

struct LinkBandwidthCalc;
typedef struct LinkBandwidthCalc LinkBandwidthCalc;

typedef struct LinkBandwidthCalcDef {
    KLEventManager *manager;  
    TransportFlow flow;
    int path_mtu_max_changes;       /* Maximum changes to path MTU. */

    unsigned int sigma_min_packets;
    unsigned int sigma_max_packets;
    double sigma_min_confidence;

    unsigned int tailgate_min_packets;
    unsigned int tailgate_max_packets;
    double tailgate_max_error;

    struct timespec timeout;
    struct timespec max_sending_interval;

    KLBufferedOutput *output_log;
} LinkBandwidthCalcDef;

LinkBandwidthCalc *
link_bandwidth_calc_new(LinkBandwidthCalcDef *def);

void
link_bandwidth_calc_free(LinkBandwidthCalc *lbc);

void
link_bandwidth_calc_start_sending(LinkBandwidthCalc *lbc);

KLException *
link_bandwidth_calc_update_output(KLBufferedOutput *bo, void *client_data);

KLException *
link_bandwidth_calc_packet_new(
    DPCapFlow *flow, const KLListNode *cur_node, int timer_index,
    int ack, void *flow_set_client_data);

void
link_bandwidth_calc_flow_new(
    DPCapFlow *flow, void *flow_set_client_data);

void
link_bandwidth_calc_flow_delete(
    DPCapFlow *flow, void *flow_set_client_data);


#endif


