/*
 * $Id: nettimer.h,v 1.16 2001/07/20 22:55:23 laik Exp $
 *
 * This file contains things needed by all parts of nettimer.
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __NETTIMER_H__
#define __NETTIMER_H__

/* System includes. */
#include <stdio.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>

/* Local includes */
#include "kl_util.h"
#include "kl_exception.h"

#ifndef NTOHL
#define NTOHL(x)        (x) = ntohl(x)
#define NTOHS(x)        (x) = ntohs(x)
#define HTONL(x)        (x) = htonl(x)
#define HTONS(x)        (x) = htons(x)
#endif

/* These are all the possible commandline arguments. */
enum {
    /* General arguments */
    ARG_EVENT_LOG, ARG_VERBOSE, ARG_VERSION,

    /* Determine if we are a client or a server. */
    ARG_RUN_DPCAP_SERVER,

    ARG_INTERFACE, ARG_DPCAP_FILTER, ARG_DPCAP_CAP_LEN, 

    /* dpcap server misc. arguments */
    ARG_DPCAP_SERVER_PORT, 

    /* dpcap server capture arguments */
    ARG_DPCAP_SERVER_PACKET_BUFFER, ARG_DPCAP_SERVER_SEND_TIMEOUT,

    /* Client misc. arguments */
    ARG_DPCAP_SERVERS, ARG_READ_TRACE,
    ARG_SAMPLE_FILE_NAME, ARG_LOG_FILE_NAME, ARG_UPDATE_FILE_NAME,
    ARG_UPDATE_INTERVAL, ARG_NO_CONVERT_ADDRESSES,
    ARG_QUALIFY_HOST_NAMES, 

    /* Client capture options */
    ARG_MAX_NUM_FLOWS, ARG_MAX_FLOW_LEN,

    /* Client calculation options */
    ARG_CALC_KERNEL_WEIGHT, ARG_CALC_PBW_WEIGHT, ARG_CALC_MBW_WEIGHT, 
    ARG_CALC_MIN_BUNCH_SIZE, ARG_CALC_MAX_BUNCH_SIZE, 
    ARG_CALC_RESTRICT_PACKET_PAIR, ARG_CALC_WINDOW_SIZE,
    ARG_CALC_MIN_DELTA_RTT, ARG_CALC_MAX_DELTA_RTT, ARG_CALC_NO_BW_RATIO,
    ARG_CALC_KERNEL_BOUND_RATIO, ARG_CALC_KERNEL_RESOLUTION,
    ARG_CALC_KERNEL_FUNCTION,

    /* Active probing options. */
    ARG_ACTIVE_PROBING_ADDRESSES, 
    ARG_ACTIVE_PROBING_PROTOCOL,
    ARG_ACTIVE_PROBING_BURST_SIZE,
    ARG_ACTIVE_PROBING_PACKET_SIZE,
    ARG_ACTIVE_PROBING_MIN_SAMPLES,
    ARG_ACTIVE_PROBING_MAX_PACKETS_SENT,
    ARG_ACTIVE_PROBING_MAX_ERROR,
    ARG_ACTIVE_PROBING_TIMEOUT,

    /* All link bandwidth mode options */
    ARG_ALL_LINK_BANDWIDTH,
    ARG_ALL_LINK_BANDWIDTH_SIGMA_MIN_PACKETS,
    ARG_ALL_LINK_BANDWIDTH_SIGMA_MAX_PACKETS,
    ARG_ALL_LINK_BANDWIDTH_SIGMA_MIN_CONFIDENCE,
    ARG_ALL_LINK_BANDWIDTH_TAILGATE_MIN_PACKETS,
    ARG_ALL_LINK_BANDWIDTH_TAILGATE_MAX_PACKETS,
    ARG_ALL_LINK_BANDWIDTH_TAILGATE_MAX_ERROR,
    ARG_ALL_LINK_BANDWIDTH_MAX_SENDING_INTERVAL,
    ARG_ALL_LINK_BANDWIDTH_TIMEOUT,

    ARG_LAST
};

/* Some exceptions */

KLExceptionClass nettimer_quit_ec;   /* Thrown when nettimer exits */

#endif
