/*
 * $Id: transport.h,v 1.3 2001/04/02 07:14:33 laik Exp $
 *
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef __TRANSPORT_H__
#define __TRANSPORT_H__

#include "kl_event.h"
#include "kl_exception.h"
#include "kl_network_protocol.h"

struct TransportSession;
typedef struct TransportSession TransportSession;

struct TransportBuffer;
typedef struct TransportBuffer TransportBuffer;

typedef struct TransportAddress {
    struct sockaddr sock_addr;
    int addr_len;
} TransportAddress;

typedef struct TransportFlow {
    TransportAddress source;         /* Source address */
    TransportAddress dest;           /* Destination address */
    int ip_protocol;                 /* IP protocol to use */
} TransportFlow;

typedef struct TransportSessionDef {
    TransportAddress source;     /* The source. */
    TransportAddress dest;       /* The ultimate destination. */
} TransportSessionDef;

TransportBuffer *
transport_new_buffer(TransportSession *session);

void
transport_free_buffer(TransportBuffer *buffer);

u_int8_t *
transport_get_buffer(TransportBuffer *buffer, int *buf_len);

KLException *
transport_new_session(TransportSessionDef *def, TransportSession **session_p);

void
transport_delete_session(TransportSession *session);

void
transport_compose_packet(
    TransportSession *session, struct sockaddr *dest, int protocol,
    unsigned int ttl, unsigned int size,
    unsigned short packet_id, TransportBuffer *t_buf);

unsigned int
transport_send_packet(TransportSession *session, TransportBuffer *t_buf);

const u_int8_t *
transport_check_packet(
    TransportSession *session, const KLNetworkProtocolPacket *packet);

unsigned short 
transport_get_packet_id(
    TransportSession *session, struct sockaddr *dest, 
    const KLNetworkProtocolPacket *packet);

void
transport_session_get_packet_sizes(
    TransportSession *session, int protocol, unsigned int *min_size,
    unsigned int *max_size);

void
transport_flow_compose(
    TransportFlow *flow, const char *source, 
    const char *source_service, const char *destination, 
    const char *destination_service);

#endif
